@@ -1,3 +1,8 @@
+def DeprecationWarning(text):
+    print(f"\033[1;31mDeprecationWarning: {text}\033[0;0m")
+
+DeprecationWarning("This package has been deprecated please use the official repldb package ( can be found at: https://pypi.org/p/replit ), if you want to keep using it, you can access the clients with _Client and _AsyncClient.")
+
 import traceback
 import asyncio
 import http3
@@ -5,6 +10,8 @@ import json
 import sys
 import os
 
+import replitdb._async as AsyncHandler
+asyncio.run = AsyncHandler.run
 class RetryError(Exception):
   pass
 
@@ -28,20 +35,10 @@ class retry():
 import requests_async
 
 
-def DeprecationWarning(text):
-    print(f"\033[1;31mDeprecationWarning: {text}\033[0;0m")
 
-
-class Client():
+class _Client():
     def __init__(self, url=os.environ['REPLIT_DB_URL']):
         self.asyncclient = AsyncClient(url)
-        self.oldadd = '''def run(self,command,*args,**kwargs):
-    try:
-      return asyncio.run(command(*args,**kwargs))
-    except:
-      print('error')
-      print(f'await {command}(*{args},**{kwargs})')
-      return exec(f'asyncio.run({command}(*{args},**{kwargs}))')'''
 
     def add(self, **args):
         return asyncio.run(self.asyncclient.add(**args))
@@ -95,7 +92,7 @@ class Client():
         asyncio.run(self.asyncclient.wipe)
 
 
-class AsyncClient():
+class _AsyncClient():
     def __init__(self, url=os.environ['REPLIT_DB_URL']):
         self.url = url
     #@retry
@@ -114,7 +111,6 @@ class AsyncClient():
             t = t2
           else:
             t = str(json.dumps(t2))
-          print(t)
           await requests_async.post(self.url, data={i:t})
     #@retry
     async def add_dict(self, add):
@@ -153,6 +149,8 @@ class AsyncClient():
 
     async def _view_str(self, view):
         request = await requests_async.get(self.url + '/' + view)
+        if(request.status_code==404):
+          return None
         return (request.text)
     #@retry
     async def _view_str_multiple(self, *args):
@@ -166,7 +164,9 @@ class AsyncClient():
 
 
     async def _view_json(self, view):
-        request = await requests_async.get(self.url + '/' + view)
+        request = await requests_async.get(self.url + '/' + str(view))
+        if(request.status_code==404):
+          return None
         return (json.loads(request.text))
     #@retry
     async def _view_json_multiple(self, *args):
