@@ -1,5 +1,11 @@
 import replitdb.commands
+def DeprecationWarning(text):
+    print(f"\033[1;31mDeprecationWarning: {text}\033[0;0m")
+
+
 def main():
+	DeprecationWarning("This package has been deprecated use the offical one found at: https://pypi.org/p/replit")
+	return
     import sys
     import os
     del sys.argv[0]
